==> v3.12.4.8.tar.gz: qcad-3.12.4.8/ts/qcadgui_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>ExitTrialDialog</name>
    <message>
        <source>Trial Version</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Version d&apos;essai</translation>
    </message>
    <message>
        <source>QCAD Trial</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">QCAD version d&apos;essai</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Cannot find user manual at: %1</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Manuel de l&apos;utilisateur ne se trouve pas à: %1</translation>
    </message>
    <message>
        <source>Unable to launch Qt Assistant (%1)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Impossible de lancer Qt Assistant (%1)</translation>
    </message>
</context>
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+126"/>
        <source>Custom</source>
        <translatorcomment>--exact match--
--file: qt_fr.ts--
Aucun objets de dimension sélectionné avec une position de texte personnalisé.
Aucun objets de dimension sélectionné avec une position de texte personnalisé
Personnalisé</translatorcomment>
        <translation>Personnalisé</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+156"/>
        <source>Invalid</source>
        <translation>Invalide</translation>
    </message>
</context>
<context>
    <name>RSingleApplication</name>
    <message>
        <source>This software is not intended for production use.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Ce logiciel n&apos;est pas destiné à une utilisation en production.</translation>
    </message>
    <message>
        <source>To continue trying out QCAD, please restart the software.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Pour continuer à essayer QCAD, s&apos;il vous plaît redémarrer le logiciel.</translation>
    </message>
    <message>
        <source>To start using QCAD without any limitations, please buy the full version for a small license fee from %1.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Pour commencer à utiliser QCAD sans aucune limitation, s&apos;il vous plaît acheter la version complète pour une petite redevance de %1.</translation>
    </message>
</context>
</TS>

==> v3.22.1.2.tar.gz: qcad-3.22.1.2/ts/qcadgui_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>ExitTrialDialog</name>
    <message>
        <source>Trial Version</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Version d&apos;essai</translation>
    </message>
    <message>
        <source>QCAD Trial</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">QCAD version d&apos;essai</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Cannot find user manual at: %1</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Manuel de l&apos;utilisateur ne se trouve pas à: %1</translation>
    </message>
    <message>
        <source>Unable to launch Qt Assistant (%1)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Impossible de lancer Qt Assistant (%1)</translation>
    </message>
</context>
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+126"/>
        <source>Custom</source>
        <translation>Personnalisé</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+195"/>
        <source>Grid</source>
        <translation>Grille</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation>Fin</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation>A l&apos;entité</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation>Perpendiculaire</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation>Tangentiel</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation>Centre</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation>Milieu</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation>Intersection</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation>Référence</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+171"/>
        <source>Invalid</source>
        <translation>Invalide</translation>
    </message>
</context>
<context>
    <name>RSingleApplication</name>
    <message>
        <source>This software is not intended for production use.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Ce logiciel n&apos;est pas destiné à une utilisation en production.</translation>
    </message>
    <message>
        <source>To continue trying out QCAD, please restart the software.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Pour continuer à essayer QCAD, s&apos;il vous plaît redémarrer le logiciel.</translation>
    </message>
    <message>
        <source>To start using QCAD without any limitations, please buy the full version for a small license fee from %1.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Pour commencer à utiliser QCAD sans aucune limitation, s&apos;il vous plaît acheter la version complète pour une petite redevance de %1.</translation>
    </message>
</context>
</TS>
